package ocaml-solo5
sectionYPositions = computeSectionYPositions($el), 10)"
x-init="setTimeout(() => sectionYPositions = computeSectionYPositions($el), 10)"
>
OCaml cross-compiler to the freestanding Solo5 backend
Install
dune-project
Dependency
Authors
Maintainers
Sources
v1.3.3.tar.gz
md5=47876167068345542f49279e8fd28896
sha512=272081ec51a6ed69c08e4e8fa64fee3df53fd84c66c0c07a653891c88b342cf74553e1c95711e4fbc18922c899a3448a649f3bd9858f8d89cae834ad2b67fffb
doc/src/stdlib/type.ml.html
Source file type.ml
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41(**************************************************************************) (* *) (* OCaml *) (* *) (* The OCaml programmers *) (* *) (* Copyright 2022 Institut National de Recherche en Informatique et *) (* en Automatique. *) (* *) (* All rights reserved. This file is distributed under the terms of *) (* the GNU Lesser General Public License version 2.1, with the *) (* special exception on linking described in the file LICENSE. *) (* *) (**************************************************************************) (* Type equality witness *) type (_, _) eq = Equal: ('a, 'a) eq (* Type identifiers *) module Id = struct type _ id = .. module type ID = sig type t type _ id += Id : t id end type !'a t = (module ID with type t = 'a) let make (type a) () : a t = (module struct type t = a type _ id += Id : t id end) let[@inline] uid (type a) ((module A) : a t) = Obj.Extension_constructor.id [%extension_constructor A.Id] let provably_equal (type a b) ((module A) : a t) ((module B) : b t) : (a, b) eq option = match A.Id with B.Id -> Some Equal | _ -> None end
sectionYPositions = computeSectionYPositions($el), 10)"
x-init="setTimeout(() => sectionYPositions = computeSectionYPositions($el), 10)"
>